[svn-commits] mmichelson: branch group/CCSS r221696 - in /team/group/CCSS: apps/ include/as...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Thu Oct 1 14:28:33 CDT 2009


Author: mmichelson
Date: Thu Oct  1 14:28:30 2009
New Revision: 221696

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=221696
Log:
Fix compilation problems.


Modified:
    team/group/CCSS/apps/app_dial.c
    team/group/CCSS/include/asterisk/ccss.h
    team/group/CCSS/main/ccss.c

Modified: team/group/CCSS/apps/app_dial.c
URL: http://svnview.digium.com/svn/asterisk/team/group/CCSS/apps/app_dial.c?view=diff&rev=221696&r1=221695&r2=221696
==============================================================================
--- team/group/CCSS/apps/app_dial.c (original)
+++ team/group/CCSS/apps/app_dial.c Thu Oct  1 14:28:30 2009
@@ -1658,7 +1658,7 @@
 		goto done;
 	}
 
-	if (ast_cc_create_root_tree_item(chan, &ignore_cc)) {
+	if (ast_cc_call_init(chan, &ignore_cc)) {
 		goto done;
 	}
 

Modified: team/group/CCSS/include/asterisk/ccss.h
URL: http://svnview.digium.com/svn/asterisk/team/group/CCSS/include/asterisk/ccss.h?view=diff&rev=221696&r1=221695&r2=221696
==============================================================================
--- team/group/CCSS/include/asterisk/ccss.h (original)
+++ team/group/CCSS/include/asterisk/ccss.h Thu Oct  1 14:28:30 2009
@@ -397,7 +397,7 @@
  * \retval 0 Success
  * \retval -1 Failure
  */
-int ast_cc_init(struct ast_channel *chan, int *ignore_cc);
+int ast_cc_call_init(struct ast_channel *chan, int *ignore_cc);
 
 /*!
  * \since 1.6.4

Modified: team/group/CCSS/main/ccss.c
URL: http://svnview.digium.com/svn/asterisk/team/group/CCSS/main/ccss.c?view=diff&rev=221696&r1=221695&r2=221696
==============================================================================
--- team/group/CCSS/main/ccss.c (original)
+++ team/group/CCSS/main/ccss.c Thu Oct  1 14:28:30 2009
@@ -657,7 +657,7 @@
 /*!
  * \brief allocate dialed_cc_interfaces datastore and initialize fields
  *
  * This function is called when Situation 1 occurs in ast_cc_init.
  * See that function for more information on what Situation 1 is.
  *
  * In this particular case, we have to do a lot of memory allocation in order
@@ -868,7 +868,7 @@
 	return 0;
 }
 
-int ast_cc_init(struct ast_channel *chan, int *ignore_cc)
+int ast_cc_call_init(struct ast_channel *chan, int *ignore_cc)
 {
 	/* There are three situations to deal with here:
 	 *
@@ -657,7 +657,7 @@
  * \brief allocate dialed_cc_interfaces datastore and initialize fields
  *
- * This function is called when Situation 1 occurs in ast_cc_init.
+ * This function is called when Situation 1 occurs in ast_cc_call_init.
  * See that function for more information on what Situation 1 is.
  *




More information about the svn-commits mailing list